@@ -215,7 +215,7 @@ static struct poptOption options[] = {
 		POPT_ARG_NONE, 
 		&gok_args.list_accessmethods, 
 		0,
-		N_("List the access methods that can used as options to other arguments."),
+		N_("List the access methods that can be used as options to other arguments."),
 		NULL
 	},
 	{
@@ -224,7 +224,7 @@ static struct poptOption options[] = {
 		POPT_ARG_NONE, 
 		&gok_args.list_actions, 
 		0,
-		N_("List the actions that can used as options to other arguments."),
+		N_("List the actions that can be used as options to other arguments."),
 		NULL
 	},
 	{
@@ -608,8 +608,8 @@ gok_main_open(gint argc, gchar *argv[])
 		
 		fprintf (stderr, "\nGOK Actions:\n");
 		if (error == NULL) {
-			list = g_slist_sort (list, (GCompareFunc)comparebasenames);
-			GSList* listhead = list;
+			GSList* listhead;
+			listhead = list = g_slist_sort (list, (GCompareFunc)comparebasenames);
 			while (list) {
 				fprintf(stderr,"%s\n",g_path_get_basename(list->data));
 				g_free(list->data);
@@ -636,8 +636,8 @@ gok_main_open(gint argc, gchar *argv[])
 		fprintf (stderr, "\nGOK Access Methods:\n");
 		if (error == NULL) {
 			gchar* base;
-			list = g_slist_sort (list, (GCompareFunc)comparebasenames);
-			GSList* listhead = list;
+			GSList* listhead;
+			listhead = list = g_slist_sort (list, (GCompareFunc)comparebasenames);
 			while (list) {
 				base = g_path_get_basename(list->data);
 				fprintf(stderr,"%s\n",base);
@@ -1481,10 +1481,12 @@ gok_main_display_scan (GokKeyboard* pKeyboard, gchar* nameKeyboard, KeyboardType
 	
 	if (pKeyboard != NULL)
 	{
+	        gok_log ("displaying %s\n", pKeyboard->Name);
 		pKB = pKeyboard;
 	}
 	else
 	{
+	        gok_log ("displaying %s\n", nameKeyboard);
 		pKB = gok_main_keyboard_find_byname (nameKeyboard);
 	}
 
@@ -1930,7 +1932,7 @@ gok_main_read_keyboards_from_dir (const char *directory, GokKeyboard *keyboard)
 				pKeyboardFirst = keyboard;
 		}
 	}
-	
+ 	g_free (pDirectoryKeyboards);
 	gok_log_leave();
 	return pKeyboardFirst;
 }
